@@ -5,7 +5,7 @@ from operator import itemgetter
 from wtforms import fields as f, validators
 from mongoengine import ReferenceField
 
-from flask.ext.mongoengine.wtf.fields import ModelSelectField, ModelSelectMultipleField
+from flask.ext.mongoengine.wtf.fields import ModelSelectField, ModelSelectMultipleField, DictField
 from flask.ext.mongoengine.wtf.models import ModelForm
 
 __all__ = (
@@ -20,6 +20,7 @@ def converts(*args):
     return _inner
 
 
+
 class ModelConverter():
     def __init__(self, converters=None):
 
@@ -134,7 +135,7 @@ class ModelConverter():
 
     @converts('DictField')
     def conv_Dict(self, model, field, kwargs):
-        return f.TextAreaField(**kwargs)
+        return DictField(**kwargs)
 
     @converts('ListField')
     def conv_List(self, model, field, kwargs):
